@@ -362,7 +362,7 @@ static void *mymemcpy(void *, void *, size_t);
 #ifdef UINTMAX_T
 #undef UINTMAX_T
 #endif	/* defined(UINTMAX_T) */
-#if HAVE_UINTMAX_T || defined(uintmax_t)
+#if defined(HAVE_UINTMAX_T) || defined(uintmax_t)
 #define UINTMAX_T uintmax_t
 #ifndef UINTMAX_MAX
 #define UINTMAX_MAX ULLONG_MAX
@@ -395,7 +395,7 @@ static void *mymemcpy(void *, void *, size_t);
 
 /* Support for intmax_t. */
 #ifndef INTMAX_T
-#if HAVE_INTMAX_T || defined(intmax_t)
+#if defined(HAVE_INTMAX_T) || defined(intmax_t)
 #define INTMAX_T intmax_t
 #else
 #define INTMAX_T LLONG
@@ -404,7 +404,7 @@ static void *mymemcpy(void *, void *, size_t);
 
 /* Support for uintptr_t. */
 #ifndef UINTPTR_T
-#if HAVE_UINTPTR_T || defined(uintptr_t)
+#if defined(HAVE_UINTPTR_T) || defined(uintptr_t)
 #define UINTPTR_T uintptr_t
 #else
 #define UINTPTR_T unsigned long int
@@ -413,7 +413,7 @@ static void *mymemcpy(void *, void *, size_t);
 
 /* Support for ptrdiff_t. */
 #ifndef PTRDIFF_T
-#if HAVE_PTRDIFF_T || defined(ptrdiff_t)
+#if defined(HAVE_PTRDIFF_T) || defined(ptrdiff_t)
 #define PTRDIFF_T ptrdiff_t
 #else
 #define PTRDIFF_T long int
@@ -850,7 +850,7 @@ rpl_vsnprintf(char *str, size_t size, const char *format, va_list args)
 				 * characters, in an implementation-defined
 				 * manner." (C99: 7.19.6.1, 8)
 				 */
-				if ((strvalue = va_arg(args, void *)) == NULL)
+				if ((strvalue = (const char *)va_arg(args, void *)) == NULL)
 					/*
 					 * We use the glibc format.  BSD prints
 					 * "0x0", SysV "0".
@@ -1513,7 +1513,7 @@ rpl_vasprintf(char **ret, const char *format, va_list ap)
 	VA_COPY(aq, ap);
 	len = vsnprintf(NULL, 0, format, aq);
 	VA_END_COPY(aq);
-	if (len < 0 || (*ret = malloc(size = len + 1)) == NULL)
+	if (len < 0 || (*ret = (char *)malloc(size = len + 1)) == NULL)
 		return -1;
 	return vsnprintf(*ret, size, format, ap);
 }
