@@ -7,17 +7,17 @@ int timer_delete(timer_t timerid CK_ATTRIBUTE_UNUSED)
      * If the system does not have timer_settime() but does have
      * setitimer() use that instead of alarm().
      */
-    struct itimerval new;
+    struct itimerval interval;
 
     /*
      * Setting values to '0' results in disabling the running timer.
      */
-    new.it_value.tv_sec = 0;
-    new.it_value.tv_usec = 0;
-    new.it_interval.tv_sec = 0;
-    new.it_interval.tv_usec = 0;
+    interval.it_value.tv_sec = 0;
+    interval.it_value.tv_usec = 0;
+    interval.it_interval.tv_sec = 0;
+    interval.it_interval.tv_usec = 0;
 
-    return setitimer(ITIMER_REAL, &new, NULL);
+    return setitimer(ITIMER_REAL, &interval, NULL);
 #else
     /*
      * There is only one timer, that used by alarm.
