@@ -265,9 +265,7 @@ void tcase_set_timeout(TCase * tc, double timeout)
 #else
     (void)tc;
     (void)timeout;
-    eprintf
-        ("This version does not support timeouts, as fork is not supported",
-         __FILE__, __LINE__);
+    /* Ignoring, as Check is not compiled with fork support. */
 #endif /* HAVE_FORK */
 }
 
@@ -288,17 +286,29 @@ void _ck_assert_failed(const char *file, int line, const char *expr, ...)
     const char *msg;
     va_list ap;
     char buf[BUFSIZ];
+    const char *to_send;
 
     send_loc_info(file, line);
 
     va_start(ap, expr);
     msg = (const char *)va_arg(ap, char *);
 
-    if(msg == NULL)
-        msg = expr;
-    vsnprintf(buf, BUFSIZ, msg, ap);
+    /*
+     * If a message was passed, format it with vsnprintf.
+     * Otherwise, print the expression as is.
+     */
+    if(msg != NULL)
+    {
+        vsnprintf(buf, BUFSIZ, msg, ap);
+        to_send = buf;
+    }
+    else
+    {
+        to_send = expr;
+    }
+
     va_end(ap);
-    send_failure_info(buf);
+    send_failure_info(to_send);
     if(cur_fork_status() == CK_FORK)
     {
 #if defined(HAVE_FORK) && HAVE_FORK==1
