@@ -79,8 +79,8 @@ CK_CPPSTART
 /* check version numbers */
 
 #define CHECK_MAJOR_VERSION (0)
-#define CHECK_MINOR_VERSION (9)
-#define CHECK_MICRO_VERSION (13)
+#define CHECK_MINOR_VERSION (10)
+#define CHECK_MICRO_VERSION (0)
 
 CK_DLL_EXP extern int CK_EXPORT check_major_version;
 CK_DLL_EXP extern int CK_EXPORT check_minor_version;
@@ -343,6 +343,9 @@ CK_DLL_EXP void CK_EXPORT tcase_add_checked_fixture(TCase * tc, SFun setup,
  * the environment variable CK_DEFAULT_TIMEOUT is defined and no timeout
  * is set, the value in the environment variable is used.
  *
+ * If Check is compile without fork() support this call is ignored,
+ * as timeouts are not possible.
+ *
  * @param tc test case to assign timeout to
  * @param timeout to use, in seconds. If the value contains a decimal
  *                 portion, but no high resolution timer is available,
@@ -474,7 +477,7 @@ CK_DLL_EXP void CK_EXPORT _ck_assert_failed(const char *file, int line,
 #define _ck_assert_int(X, OP, Y) do { \
   intmax_t _ck_x = (X); \
   intmax_t _ck_y = (Y); \
-  ck_assert_msg(_ck_x OP _ck_y, "Assertion '%s' failed: %s==%jd, %s==%jd", #X#OP#Y, #X, _ck_x, #Y, _ck_y); \
+  ck_assert_msg(_ck_x OP _ck_y, "Assertion '%s' failed: %s == %jd, %s == %jd", #X" "#OP" "#Y, #X, _ck_x, #Y, _ck_y); \
 } while (0)
 
 /**
@@ -559,7 +562,7 @@ CK_DLL_EXP void CK_EXPORT _ck_assert_failed(const char *file, int line,
 #define _ck_assert_uint(X, OP, Y) do { \
   uintmax_t _ck_x = (X); \
   uintmax_t _ck_y = (Y); \
-  ck_assert_msg(_ck_x OP _ck_y, "Assertion '%s' failed: %s==%ju, %s==%ju", #X#OP#Y, #X, _ck_x, #Y, _ck_y); \
+  ck_assert_msg(_ck_x OP _ck_y, "Assertion '%s' failed: %s == %ju, %s == %ju", #X" "#OP" "#Y, #X, _ck_x, #Y, _ck_y); \
 } while (0)
 /**
  * Check two unsigned integers to determine if X==Y
@@ -647,7 +650,7 @@ CK_DLL_EXP void CK_EXPORT _ck_assert_failed(const char *file, int line,
   const char* _ck_x = (X); \
   const char* _ck_y = (Y); \
   ck_assert_msg(0 OP strcmp(_ck_y, _ck_x), \
-    "Assertion '%s' failed: %s==\"%s\", %s==\"%s\"", #X#OP#Y, #X, _ck_x, #Y, _ck_y); \
+    "Assertion '%s' failed: %s == \"%s\", %s == \"%s\"", #X" "#OP" "#Y, #X, _ck_x, #Y, _ck_y); \
 } while (0)
 /**
  * Check two strings to determine if 0==strcmp(X,Y)
@@ -733,7 +736,7 @@ CK_DLL_EXP void CK_EXPORT _ck_assert_failed(const char *file, int line,
 #define _ck_assert_ptr(X, OP, Y) do { \
   const void* _ck_x = (X); \
   const void* _ck_y = (Y); \
-  ck_assert_msg(_ck_x OP _ck_y, "Assertion '%s' failed: %s==%#x, %s==%#x", #X#OP#Y, #X, _ck_x, #Y, _ck_y); \
+  ck_assert_msg(_ck_x OP _ck_y, "Assertion '%s' failed: %s == %#x, %s == %#x", #X" "#OP" "#Y, #X, _ck_x, #Y, _ck_y); \
 } while (0)
 
 /**
@@ -1206,6 +1209,9 @@ CK_DLL_EXP enum fork_status CK_EXPORT srunner_fork_status(SRunner * sr);
  * If set to CK_FORK or CK_NOFORK, the environment variable
  * if defined is ignored.
  *
+ * If Check is compiled without support for fork(), attempting
+ * to set the status to CK_FORK is ignored.
+ *
  * @param sr suite runner to assign the fork status to
  * @param fstat fork status to assign
  *
@@ -1224,9 +1230,13 @@ CK_DLL_EXP void CK_EXPORT srunner_set_fork_status(SRunner * sr,
  * the process group will be killed; using this wrapper will prevent
  * orphan processes.
  *
+ * If Check is compiled without fork() support this call simply
+ * return -1 and does nothing.
+ *
  * @return On success, the PID of the child process is returned in
  *          the parent, and 0 is returned in the child.  On failure,
- *          an error will be printed and exit() invoked.
+ *          a value of -1 is returned to the parent process and no
+ *          child process is created.
  *
  * @since 0.9.3
  */
@@ -1240,6 +1250,9 @@ CK_DLL_EXP pid_t CK_EXPORT check_fork(void);
  * exited without error, exit(EXIT_SUCCESS) is invoked; otherwise
  * exit(EXIT_FAILURE) is invoked.
  *
+ * If Check is compiled without support for fork(), this invokes
+ * exit(EXIT_FAILURE).
+ *
  * @param pid process to wait for, created by check_fork()
  *
  * @since 0.9.3
