@@ -1,3 +1,5 @@
+#include "../lib/libcompat.h"
+
 #include <stdlib.h>
 #include <string.h>
 #include <check.h>
@@ -21,9 +23,11 @@ static void limit_teardown (void)
 
 START_TEST(test_summary)
 {
-  fail_unless(strcmp(sr_stat_str(sr),
+  char * string = sr_stat_str(sr);
+  ck_assert_msg(strcmp(string,
 		     "100%: Checks: 0, Failures: 0, Errors: 0") == 0,
 	      "Bad statistics string for empty suite");
+  free(string);
 }
 END_TEST
 
