@@ -57,41 +57,42 @@ static master_test_t master_tests[] = {
   { "Simple Tests", CK_FAILURE, "Failed" },
   { "Simple Tests", CK_FAILURE, "Assertion 'x == y' failed" },
   { "Simple Tests", CK_FAILURE, "Assertion '0' failed" },
-  { "Simple Tests", CK_FAILURE, "Assertion 'x==y' failed: x==3, y==4" },
-  { "Simple Tests", CK_FAILURE, "Assertion '3%d==2%f' failed: 3%d==1, 2%f==0" },
-  { "Simple Tests", CK_FAILURE, "Assertion 'x!=y' failed: x==3, y==3" },
-  { "Simple Tests", CK_FAILURE, "Assertion '3%d!=3%f' failed: 3%d==1, 3%f==1" },
-  { "Simple Tests", CK_FAILURE, "Assertion 'x<x' failed: x==2, x==2" },
-  { "Simple Tests", CK_FAILURE, "Assertion '3%d<3%f' failed: 3%d==1, 3%f==0" },
-  { "Simple Tests", CK_FAILURE, "Assertion 'y<=x' failed: y==3, x==2" },
-  { "Simple Tests", CK_FAILURE, "Assertion '3%d<=2%f' failed: 3%d==1, 2%f==0" },
-  { "Simple Tests", CK_FAILURE, "Assertion 'y>y' failed: y==3, y==3" },
-  { "Simple Tests", CK_FAILURE, "Assertion '3%d>3%f' failed: 3%d==0, 3%f==1" },
-  { "Simple Tests", CK_FAILURE, "Assertion 'x>=y' failed: x==2, y==3" },
-  { "Simple Tests", CK_FAILURE, "Assertion '3%d>=4%f' failed: 3%d==0, 4%f==1" },
+  { "Simple Tests", CK_FAILURE, "Assertion '1%f == 1' failed" },
+  { "Simple Tests", CK_FAILURE, "Assertion 'x == y' failed: x == 3, y == 4" },
+  { "Simple Tests", CK_FAILURE, "Assertion '3%d == 2%f' failed: 3%d == 1, 2%f == 0" },
+  { "Simple Tests", CK_FAILURE, "Assertion 'x != y' failed: x == 3, y == 3" },
+  { "Simple Tests", CK_FAILURE, "Assertion '3%d != 3%f' failed: 3%d == 1, 3%f == 1" },
+  { "Simple Tests", CK_FAILURE, "Assertion 'x < x' failed: x == 2, x == 2" },
+  { "Simple Tests", CK_FAILURE, "Assertion '3%d < 3%f' failed: 3%d == 1, 3%f == 0" },
+  { "Simple Tests", CK_FAILURE, "Assertion 'y <= x' failed: y == 3, x == 2" },
+  { "Simple Tests", CK_FAILURE, "Assertion '3%d <= 2%f' failed: 3%d == 1, 2%f == 0" },
+  { "Simple Tests", CK_FAILURE, "Assertion 'y > y' failed: y == 3, y == 3" },
+  { "Simple Tests", CK_FAILURE, "Assertion '3%d > 3%f' failed: 3%d == 0, 3%f == 1" },
+  { "Simple Tests", CK_FAILURE, "Assertion 'x >= y' failed: x == 2, y == 3" },
+  { "Simple Tests", CK_FAILURE, "Assertion '3%d >= 4%f' failed: 3%d == 0, 4%f == 1" },
   { "Simple Tests", CK_PASS,    "Passed" },
-  { "Simple Tests", CK_FAILURE, "Assertion 'x==y' failed: x==3, y==4" },
-  { "Simple Tests", CK_FAILURE, "Assertion '3%d==1%f' failed: 3%d==1, 1%f==0" },
-  { "Simple Tests", CK_FAILURE, "Assertion 'x!=y' failed: x==3, y==3" },
-  { "Simple Tests", CK_FAILURE, "Assertion '1%d!=1%f' failed: 1%d==0, 1%f==0" },
-  { "Simple Tests", CK_FAILURE, "Assertion 'x<x' failed: x==2, x==2" },
-  { "Simple Tests", CK_FAILURE, "Assertion '3%d<1%f' failed: 3%d==1, 1%f==0" },
-  { "Simple Tests", CK_FAILURE, "Assertion 'y<=x' failed: y==3, x==2" },
-  { "Simple Tests", CK_FAILURE, "Assertion '3%d<=1%f' failed: 3%d==1, 1%f==0" },
-  { "Simple Tests", CK_FAILURE, "Assertion 'y>y' failed: y==3, y==3" },
-  { "Simple Tests", CK_FAILURE, "Assertion '1%d>3%f' failed: 1%d==0, 3%f==1" },
-  { "Simple Tests", CK_FAILURE, "Assertion 'x>=y' failed: x==2, y==3" },
-  { "Simple Tests", CK_FAILURE, "Assertion '1%d>=3%f' failed: 1%d==0, 3%f==1" },
+  { "Simple Tests", CK_FAILURE, "Assertion 'x == y' failed: x == 3, y == 4" },
+  { "Simple Tests", CK_FAILURE, "Assertion '3%d == 1%f' failed: 3%d == 1, 1%f == 0" },
+  { "Simple Tests", CK_FAILURE, "Assertion 'x != y' failed: x == 3, y == 3" },
+  { "Simple Tests", CK_FAILURE, "Assertion '1%d != 1%f' failed: 1%d == 0, 1%f == 0" },
+  { "Simple Tests", CK_FAILURE, "Assertion 'x < x' failed: x == 2, x == 2" },
+  { "Simple Tests", CK_FAILURE, "Assertion '3%d < 1%f' failed: 3%d == 1, 1%f == 0" },
+  { "Simple Tests", CK_FAILURE, "Assertion 'y <= x' failed: y == 3, x == 2" },
+  { "Simple Tests", CK_FAILURE, "Assertion '3%d <= 1%f' failed: 3%d == 1, 1%f == 0" },
+  { "Simple Tests", CK_FAILURE, "Assertion 'y > y' failed: y == 3, y == 3" },
+  { "Simple Tests", CK_FAILURE, "Assertion '1%d > 3%f' failed: 1%d == 0, 3%f == 1" },
+  { "Simple Tests", CK_FAILURE, "Assertion 'x >= y' failed: x == 2, y == 3" },
+  { "Simple Tests", CK_FAILURE, "Assertion '1%d >= 3%f' failed: 1%d == 0, 3%f == 1" },
   { "Simple Tests", CK_PASS,    "Passed" },
-  { "Simple Tests", CK_FAILURE, "Assertion '\"test1\"==s' failed: \"test1\"==\"test1\", s==\"test2\"" },
-  { "Simple Tests", CK_FAILURE, "Assertion 't!=s' failed: t==\"test2\", s==\"test2\"" },
-  { "Simple Tests", CK_FAILURE, "Assertion 's<s' failed: s==\"test1\", s==\"test1\"" },
-  { "Simple Tests", CK_FAILURE, "Assertion 't<=s' failed: t==\"test2\", s==\"test1\"" },
-  { "Simple Tests", CK_FAILURE, "Assertion 't>t' failed: t==\"test2\", t==\"test2\"" },
-  { "Simple Tests", CK_FAILURE, "Assertion 's>=t' failed: s==\"test1\", t==\"test2\"" },
+  { "Simple Tests", CK_FAILURE, "Assertion '\"test1\" == s' failed: \"test1\" == \"test1\", s == \"test2\"" },
+  { "Simple Tests", CK_FAILURE, "Assertion 't != s' failed: t == \"test2\", s == \"test2\"" },
+  { "Simple Tests", CK_FAILURE, "Assertion 's < s' failed: s == \"test1\", s == \"test1\"" },
+  { "Simple Tests", CK_FAILURE, "Assertion 't <= s' failed: t == \"test2\", s == \"test1\"" },
+  { "Simple Tests", CK_FAILURE, "Assertion 't > t' failed: t == \"test2\", t == \"test2\"" },
+  { "Simple Tests", CK_FAILURE, "Assertion 's >= t' failed: s == \"test1\", t == \"test2\"" },
   { "Simple Tests", CK_PASS,    "Passed" },
-  { "Simple Tests", CK_FAILURE, "Assertion 'x==y' failed: x==0x1, y==0x2" },
-  { "Simple Tests", CK_FAILURE, "Assertion 'x!=z' failed: x==0x1, z==0x1" },
+  { "Simple Tests", CK_FAILURE, "Assertion 'x == y' failed: x == 0x1, y == 0x2" },
+  { "Simple Tests", CK_FAILURE, "Assertion 'x != z' failed: x == 0x1, z == 0x1" },
   
 #if defined(HAVE_FORK) && HAVE_FORK==1
   { "Signal Tests", CK_ERROR,   signal_11_str },
@@ -267,6 +268,37 @@ START_TEST(test_check_ntests_run)
 }
 END_TEST
 
+/**
+ * Given a string, return a new string that is a copy
+ * of the original exception that every occurance of
+ * % is replaced with %%. This escapes the %
+ * symbol for passing to printf.
+ *
+ * The passed in string is not modified. Note though
+ * that the returned string is allocated memory that
+ * must be freed by the caller.
+ */
+char * escape_percent(const char *original, size_t original_size);
+char * escape_percent(const char *original, size_t original_size)
+{
+  /* In the worst case every character is a %*/
+  char *result = (char*)malloc(original_size*2);
+
+  size_t read_index;
+  size_t write_index;
+  for(read_index = write_index = 0; read_index < original_size; read_index++, write_index++)
+  {
+    result[write_index] = original[read_index];
+    if(result[write_index] == '%')
+    {
+      /* Place a duplicate % next to the one just read, to escape it */
+      result[++write_index] = '%';
+    }
+  }
+
+  return result;
+}
+
 START_TEST(test_check_failure_msgs)
 {
   int i;
@@ -286,10 +318,22 @@ START_TEST(test_check_failure_msgs)
     ck_assert_msg(tr != NULL, NULL);
     got_msg = tr_msg(tr);
     expected_msg = master_tests[i].msg;
+
     if (strcmp(got_msg, expected_msg) != 0) {      
-      char *emsg = (char *)malloc(MAXSTR);
-      snprintf(emsg, MAXSTR,"For test %d: Expected %s, got %s",
+      char *emsg;
+      char *tmp = (char *)malloc(MAXSTR);
+      snprintf(tmp, MAXSTR,"For test %d: Expected %s, got %s",
                i, expected_msg, got_msg);
+
+      /*
+       * NOTE: ck_abort_msg() will take the passed string
+       * and feed it to printf. We need to escape any
+       * '%' found, else they will result in odd formatting
+       * in ck_abort_msg().
+       */
+      emsg = escape_percent(tmp, MAXSTR);
+      free(tmp);
+
       ck_abort_msg(emsg);
       free(emsg);
     }
@@ -394,9 +438,20 @@ START_TEST(test_check_all_msgs)
   const char *msg;
   msg = tr_msg(tr_all_array[_i]);
   if (strcmp(msg, master_tests[_i].msg) != 0) {
-    char *emsg = (char *)malloc (MAXSTR);
-    snprintf(emsg, MAXSTR,"Expected %s, got %s",
+    char *emsg;
+    char *tmp = (char *)malloc (MAXSTR);
+    snprintf(tmp, MAXSTR,"Expected %s, got %s",
              master_tests[_i].msg, msg);
+
+   /*
+    * NOTE: ck_abort_msg() will take the passed string
+    * and feed it to printf. We need to escape any
+    * '%' found, else they will result in odd formatting
+    * in ck_abort_msg().
+    */
+    emsg = escape_percent(tmp, MAXSTR);
+    free(tmp);
+
     ck_abort_msg(emsg);
     free(emsg);
   }
@@ -502,8 +557,13 @@ void setup (void)
    * Create file that will contain the line numbers of the failures
    * in check_check_sub.c, as they occur.
    */
+#if !HAVE_MKSTEMP
   line_num_failures_file_name = tempnam(NULL, "check_error_linenums_");
   line_num_failures = fopen(line_num_failures_file_name, "w+b");
+#else
+  line_num_failures_file_name = strdup("check_error_linenums_XXXXXX");
+  line_num_failures = fdopen(mkstemp(line_num_failures_file_name), "w+b");
+#endif
 
   srunner_add_suite(sr, make_sub2_suite());
 
